rcu_run_callbacks

Function rcu_run_callbacks 

pub fn rcu_run_callbacks() -> bool
Advances the RCU state machine if work is pending and runs ready callbacks.

If callbacks are pending, this runs two grace periods and invokes any ready callbacks.

Returns true if callbacks were processed, or false if no work was pending.