rcu_synchronize

Function rcu_synchronize 

pub fn rcu_synchronize()
Block until all in-flight read operations have completed for callbacks registered prior to this call.

Note: This function does not advance the RCU state machine itself; it registers a callback and blocks until that callback is run. If no thread is calling rcu_run_callbacks() (for example, via a dedicated advancer thread), this function will block indefinitely.