RcuBox

Struct RcuBox 

pub struct RcuBox<T: Send + Sync + 'static> { /* private fields */ }
An RCU (Read-Copy-Update) wrapper around a Box.

The Box can be dereferenced from multiple threads concurrently without blocking. When the Box is replaced, reads may continue to see the old Box pointer for some period of time.

Implementations

Source

impl<T: Send + Sync + 'static> RcuBox<T>

pub fn new(data: T) -> Self

Create a new RCU wrapped Box from a value.

pub fn read(&self) -> RcuReadGuard<T>

Read the value of the wrapped Box.

The object referenced by the Box will remain valid until the RcuReadGuard is dropped. However, another thread running concurrently might see a different object.

pub fn as_ref<'a>(&self, scope: &'a RcuReadScope) -> &'a T

Returns a reference to the value of the wrapped Box.

The object referenced by the Box will remain valid until the RcuReadScope is dropped. However, another thread running concurrently might see a different object.

pub fn update(&self, data: T)

Write a new Boxed value to the RCU wrapper.

Concurrent readers may continue to see the old boxed object until the RCU state machine has made sufficient progress to ensure that no concurrent readers are holding read guards.

Source

impl<T: Clone + Send + Sync + 'static> RcuBox<T>

pub fn cloned(&self) -> T

Returns a clone of the value of the wrapped Box.

The clone is detached from any RCU read scope.