pub struct RcuReadGuard<T> { /* private fields */ }Expand description
A read guard for an object managed by the RCU state machine.
This guard ensures that the object remains valid until the guard is dropped.
Implementations
Sourceimpl<T> RcuReadGuard<T>
impl<T> RcuReadGuard<T>
Sourcepub fn scope(&self) -> &RcuReadScope
pub fn scope(&self) -> &RcuReadScope
Get the scope in which the object is valid.
Sourcepub fn as_ptr(&self) -> *const T
pub fn as_ptr(&self) -> *const T
Get the raw pointer to the object.
This function returns the raw pointer to the object. The caller is responsible for ensuring that the pointer is not referenced after the guard is dropped.
To use the Rust borrow checker to enforce that the object is not accessed after the guard is
dropped, use the Deref implementation.