RcuThreadRegistration

Struct RcuThreadRegistration 

pub struct RcuThreadRegistration { /* private fields */ }
An RAII guard that keeps the current thread registered with RCU and RSEQ.

Unregisters the thread when dropped.

Implementations

Source

impl RcuThreadRegistration

pub fn leak(self)

Leaks the registration, keeping the current thread registered indefinitely.