pub unsafe trait RcuDroppable: Send + 'static { }Expand description
Marker trait for types that are safe to be dropped on the RCU worker / drop execution path.
Safety
Types implementing this trait MUST NOT have Drop side-effects that block or are time or thread sensitive.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".