pub fn rcu_drop<T: RcuDroppable + Sync>(value: T)Expand description
Schedule the object to be dropped after all in-flight read operations have completed.
To wait until the object is dropped, call rcu_synchronize(). Note that rcu_synchronize()
requires an advancer thread or a thread calling rcu_run_callbacks() to make progress and drop
the object.
To be safely passed to rcu_drop either directly, or indirectly by an rcu container, the type must implement the marker trait RcuDroppable to indicate:
- Dropping T must not take locks or otherwise block.
- It is safe to drop T from an arbitrary thread.
- There is no guarantee as to when T will actually be dropped unless
rcu_synchronize()orrcu_run_callbacks()is called.