rcu_run_callbacks

Function rcu_run_callbacks 

pub fn rcu_run_callbacks() -> bool
If any callbacks have been scheduled from this thread, call rcu_synchronize.

If any callbacks have been scheduled from this thread, this function blocks until the callbacks are unblocked and ready to be run (but have not yet necessarily finished, or even started). If no callbacks have been scheduled from this thread, this function returns immediately.

Returns true if callbacks were run, which indicates that new callbacks might have been scheduled as a result of executing the existing callbacks. Returns false otherwise.