pub fn rcu_run_callbacks()Expand description
If any callbacks have been scheduled from this thread, call rcu_synchronize.
If any callbacks have been scheduled from this thread, this function will block until the callbacks are unblocked and ready to be run (but have not yet necessarily finished, or even started). If no callbacks have been scheduled from this thread, this function will return immediately.