RcuOptionBox

Struct RcuOptionBox 

pub struct RcuOptionBox<T: Send + Sync + 'static> { /* private fields */ }
An RCU (Read-Copy-Update) wrapper around Option<Box>.

The Box can be dereferenced from multiple threads concurrently without blocking. When the Box is replaced, reads may continue to see the old Box for some period of time.

Implementations

Source

impl<T: Send + Sync + 'static> RcuOptionBox<T>

pub fn new(data: Option<T>) -> Self

Create a new RCU Cell from a value.

pub fn read(&self) -> Option<RcuReadGuard<T>>

Read the value of the wrapped Box, if present.

The object referenced by the Box will remain valid until the RcuReadGuard is dropped. However, another thread running concurrently might see a different object.

pub fn as_ref<'a>(&self, scope: &'a RcuReadScope) -> Option<&'a T>

Returns a reference to the value of the wrapped Box, if present.

The object referenced by the Box will remain valid until the RcuReadScope is dropped. However, another thread running concurrently might see a different object.

pub fn update(&self, data: Option<T>)

Write a new value to the RCU wrapper.

Concurrent readers may continue to see the old value until the RCU state machine has made sufficient progress to ensure that no concurrent readers are holding read guards.

Source

impl<T: Clone + Send + Sync + 'static> RcuOptionBox<T>

pub fn cloned(&self) -> Option<T>

Returns a clone of the value of the wrapped Box, if present.

The clone is detached from any RCU read scope.