RcuWeak

Struct RcuWeak 

pub struct RcuWeak<T: Send + Sync + 'static> { /* private fields */ }
An RCU (Read-Copy-Update) wrapper around a Weak pointer.

The weak pointer can be read and upgraded from multiple threads concurrently without blocking. When the weak pointer is replaced, reads may continue to see the old weak pointer for some period of time.

Implementations

Source

impl<T: Send + Sync + 'static> RcuWeak<T>

pub fn new(data: Weak<T>) -> Self

Create a new RCU wrapper around a Weak pointer.

pub fn upgrade(&self) -> Option<Arc<T>>

Try to upgrade the wrapped Weak pointer to an Arc.

Returns None if the weak pointer has expired and the referenced object was destroyed or if the RcuWeak is in a transient state during drop.

pub fn to_weak(&self) -> Weak<T>

Create a new Weak pointer to the object referenced by the wrapped Weak pointer.

pub fn ptr_eq(&self, other: &Weak<T>) -> bool

Check if the wrapped weak pointer points to the same allocation as other.

pub fn update(&self, data: Weak<T>)

Write a new Weak pointer to the RCU wrapper.

Concurrent readers may continue to see the old weak pointer until the RCU state machine has made sufficient progress to ensure that no concurrent readers are holding read guards.