pub struct RcuWeak<T: Send + Sync + 'static> { /* private fields */ }Expand description
An RCU (Read-Copy-Update) wrapper around a Weak pointer.
The weak pointer can be read and upgraded from multiple threads concurrently without blocking. When the weak pointer is replaced, reads may continue to see the old weak pointer for some period of time.
Implementations
Sourceimpl<T: Send + Sync + 'static> RcuWeak<T>
impl<T: Send + Sync + 'static> RcuWeak<T>