pub unsafe fn rcu_ptr_upgrade<'a, T>(ptr: RcuPtrRef<'a, T>) -> Option<Arc<T>>Expand description
Reconstruct an Arc from an RcuPtrRef by upgrading its strong count if it’s safe to do so.
Returns None if the strong count of the underlying Arc has dropped to zero or if the
pointer is null.
Safety
The caller must guarantee that the pointer was obtained from Arc::into_raw() or
Weak::into_raw().